INSTALLED_APPS = [
    "django.contrib.auth",
    "django.contrib.contenttypes",
    "django.contrib.sites",
    "fevernotifications",
]
SITE_ID = 1
MIDDLEWARE_CLASSES = ()
SECRET_KEY = 'sdgfjodsigdfs'
